InsightsConfigService

Struct InsightsConfigService 

pub struct InsightsConfigService { /* private fields */ }
Implements a client for the Developer Connect API.

Example

use google_cloud_gax::paginator::ItemPaginator as _;
    let client = InsightsConfigService::builder().build().await?;
    let parent = "parent_value";
    let mut list = client.list_insights_configs()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }

Service Description

Creates and manages InsightsConfigs.

The InsightsConfig resource is the core configuration object to capture events from your Software Development Lifecycle. It acts as the central hub for managing how Developer Connect understands your application, its runtime environments, and the artifacts deployed within them. A user can create an InsightsConfig, list previously-requested InsightsConfigs or get InsightsConfigs by their ID to determine the status of the InsightsConfig.

Configuration

To configure InsightsConfigService use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

  • with_endpoint(): by default this client uses the global default endpoint (https://developerconnect.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default.
  • with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.

Pooling and Cloning

InsightsConfigService holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap InsightsConfigService in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl InsightsConfigService

pub fn builder() -> ClientBuilder

Returns a builder for InsightsConfigService.

let client = InsightsConfigService::builder().build().await?;
pub fn from_stub<T>(stub: T) -> Self
where T: InsightsConfigService + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn list_insights_configs(&self) -> ListInsightsConfigs

Lists InsightsConfigs in a given project and location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_developerconnect_v1::Result;
async fn sample(
   client: &InsightsConfigService, parent: &str
) -> Result<()> {
    let mut list = client.list_insights_configs()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn create_insights_config(&self) -> CreateInsightsConfig

Creates a new InsightsConfig in a given project and location.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_developerconnect_v1::model::InsightsConfig;
use google_cloud_developerconnect_v1::Result;
async fn sample(
   client: &InsightsConfigService, parent: &str
) -> Result<()> {
    let response = client.create_insights_config()
        .set_parent(parent)
        .set_insights_config(
            InsightsConfig::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_insights_config(&self) -> GetInsightsConfig

Gets details of a single Insight.

Example
use google_cloud_developerconnect_v1::Result;
async fn sample(
   client: &InsightsConfigService, name: &str
) -> Result<()> {
    let response = client.get_insights_config()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_insights_config(&self) -> UpdateInsightsConfig

Updates the parameters of a single InsightsConfig.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_developerconnect_v1::model::InsightsConfig;
use google_cloud_developerconnect_v1::Result;
async fn sample(
   client: &InsightsConfigService, name: &str
) -> Result<()> {
    let response = client.update_insights_config()
        .set_insights_config(
            InsightsConfig::new().set_name(name)/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_insights_config(&self) -> DeleteInsightsConfig

Deletes a single Insight.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_developerconnect_v1::Result;
async fn sample(
   client: &InsightsConfigService, name: &str
) -> Result<()> {
    client.delete_insights_config()
        .set_name(name)
        .poller().until_done().await?;
    Ok(())
}
pub fn get_deployment_event(&self) -> GetDeploymentEvent

Gets a single Deployment Event.

Example
use google_cloud_developerconnect_v1::Result;
async fn sample(
   client: &InsightsConfigService, name: &str
) -> Result<()> {
    let response = client.get_deployment_event()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_deployment_events(&self) -> ListDeploymentEvents

Lists Deployment Events in a given insights config.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_developerconnect_v1::Result;
async fn sample(
   client: &InsightsConfigService, parent: &str
) -> Result<()> {
    let mut list = client.list_deployment_events()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn list_locations(&self) -> ListLocations

Lists information about the supported locations for this service. This method can be called in two ways:

  • List all public locations: Use the path GET /v1/locations.
  • List project-visible locations: Use the path GET /v1/projects/{project_id}/locations. This may include public locations as well as private or other locations specifically visible to the project.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_developerconnect_v1::Result;
async fn sample(
   client: &InsightsConfigService
) -> Result<()> {
    let mut list = client.list_locations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_location(&self) -> GetLocation

Gets information about a location.

Example
use google_cloud_developerconnect_v1::Result;
async fn sample(
   client: &InsightsConfigService
) -> Result<()> {
    let response = client.get_location()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_operations(&self) -> ListOperations

Provides the Operations service functionality in this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_developerconnect_v1::Result;
async fn sample(
   client: &InsightsConfigService
) -> Result<()> {
    let mut list = client.list_operations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_operation(&self) -> GetOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_developerconnect_v1::Result;
async fn sample(
   client: &InsightsConfigService
) -> Result<()> {
    let response = client.get_operation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_operation(&self) -> DeleteOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_developerconnect_v1::Result;
async fn sample(
   client: &InsightsConfigService
) -> Result<()> {
    client.delete_operation()
        /* set fields */
        .send().await?;
    Ok(())
}
pub fn cancel_operation(&self) -> CancelOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_developerconnect_v1::Result;
async fn sample(
   client: &InsightsConfigService
) -> Result<()> {
    client.cancel_operation()
        /* set fields */
        .send().await?;
    Ok(())
}