Module model

Module model 

The messages and enums that are part of this client library.

Modules

account_connector
Defines additional types related to AccountConnector.
artifact_config
Defines additional types related to ArtifactConfig.
connection
Defines additional types related to Connection.
deployment_event
Defines additional types related to DeploymentEvent.
fetch_git_hub_installations_response
Defines additional types related to FetchGitHubInstallationsResponse.
fetch_git_refs_request
Defines additional types related to FetchGitRefsRequest.
finish_o_auth_request
Defines additional types related to FinishOAuthRequest.
generic_http_endpoint_config
Defines additional types related to GenericHTTPEndpointConfig.
git_hub_config
Defines additional types related to GitHubConfig.
insights_config
Defines additional types related to InsightsConfig.
installation_state
Defines additional types related to InstallationState.
provider_o_auth_config
Defines additional types related to ProviderOAuthConfig.
runtime_config
Defines additional types related to RuntimeConfig.
start_o_auth_response
Defines additional types related to StartOAuthResponse.

Structs

AccountConnector
AccountConnector encapsulates what a platform administrator needs to configure for users to connect to the service providers, which includes, among other fields, the OAuth client ID, client secret, and authorization and token endpoints.
AppHubService
AppHubService represents the App Hub Service.
AppHubWorkload
AppHubWorkload represents the App Hub Workload.
ArtifactConfig
The artifact config of the artifact that is deployed.
ArtifactDeployment
The ArtifactDeployment resource represents the deployment of the artifact within the InsightsConfig resource.
BitbucketCloudConfig
Configuration for connections to an instance of Bitbucket Cloud.
BitbucketDataCenterConfig
Configuration for connections to an instance of Bitbucket Data Center.
Connection
Message describing Connection object
CreateAccountConnectorRequest
CreateConnectionRequest
Message for creating a Connection
CreateGitRepositoryLinkRequest
Message for creating a GitRepositoryLink
CreateInsightsConfigRequest
Request for creating an InsightsConfig.
CryptoKeyConfig
The crypto key configuration. This field is used by the Customer-managed encryption keys (CMEK) feature.
DeleteAccountConnectorRequest
Message for deleting a AccountConnector
DeleteConnectionRequest
Message for deleting a Connection
DeleteGitRepositoryLinkRequest
Message for deleting a GitRepositoryLink
DeleteInsightsConfigRequest
Request for deleting an InsightsConfig.
DeleteSelfRequest
Message for deleting a User of the user themselves.
DeleteUserRequest
Message for deleting a User
DeploymentEvent
The DeploymentEvent resource represents the deployment of the artifact within the InsightsConfig resource.
ExchangeError
Message for representing an error from exchanging OAuth tokens.
FetchAccessTokenRequest
Message for fetching an OAuth access token.
FetchAccessTokenResponse
Message for responding to getting an OAuth access token.
FetchGitHubInstallationsRequest
Request for fetching github installations.
FetchGitHubInstallationsResponse
Response of fetching github installations.
FetchGitRefsRequest
Request for fetching git refs.
FetchGitRefsResponse
Response for fetching git refs.
FetchLinkableGitRepositoriesRequest
Request message for FetchLinkableGitRepositoriesRequest.
FetchLinkableGitRepositoriesResponse
Response message for FetchLinkableGitRepositories.
FetchReadTokenRequest
Message for fetching SCM read token.
FetchReadTokenResponse
Message for responding to get read token.
FetchReadWriteTokenRequest
Message for fetching SCM read/write token.
FetchReadWriteTokenResponse
Message for responding to get read/write token.
FetchSelfRequest
Message for fetching a User of the user themselves.
FinishOAuthRequest
Message for finishing an OAuth flow.
FinishOAuthResponse
Message for responding to finishing an OAuth flow.
GKEWorkload
GKEWorkload represents the Google Kubernetes Engine runtime.
GenericHTTPEndpointConfig
Defines the configuration for connections to an HTTP service provider.
GetAccountConnectorRequest
Message for getting a AccountConnector
GetConnectionRequest
Message for getting a Connection
GetDeploymentEventRequest
Request for getting a DeploymentEvent.
GetGitRepositoryLinkRequest
Message for getting a GitRepositoryLink
GetInsightsConfigRequest
Request for getting an InsightsConfig.
GitHubConfig
Configuration for connections to github.com.
GitHubEnterpriseConfig
Configuration for connections to an instance of GitHub Enterprise.
GitLabConfig
Configuration for connections to gitlab.com.
GitLabEnterpriseConfig
Configuration for connections to an instance of GitLab Enterprise.
GitProxyConfig
The git proxy configuration.
GitRepositoryLink
Message describing the GitRepositoryLink object
GoogleArtifactAnalysis
Google Artifact Analysis configurations.
GoogleArtifactRegistry
Google Artifact Registry configurations.
GoogleCloudRun
GoogleCloudRun represents the Cloud Run runtime.
InsightsConfig
The InsightsConfig resource is the core configuration object to capture events from your Software Development Lifecycle. It acts as the central hub for managing how Developer Connect understands your application, its runtime environments, and the artifacts deployed within them.
InstallationState
Describes stage and necessary actions to be taken by the user to complete the installation. Used for GitHub and GitHub Enterprise based connections.
LinkableGitRepository
LinkableGitRepository represents a git repository that can be linked to a connection.
ListAccountConnectorsRequest
Message for requesting list of AccountConnectors
ListAccountConnectorsResponse
Message for response to listing AccountConnectors
ListConnectionsRequest
Message for requesting list of Connections
ListConnectionsResponse
Message for response to listing Connections
ListDeploymentEventsRequest
Request for requesting list of DeploymentEvents.
ListDeploymentEventsResponse
Response to listing DeploymentEvents.
ListGitRepositoryLinksRequest
Message for requesting a list of GitRepositoryLinks
ListGitRepositoryLinksResponse
Message for response to listing GitRepositoryLinks
ListInsightsConfigsRequest
Request for requesting list of InsightsConfigs.
ListInsightsConfigsResponse
Request for response to listing InsightsConfigs.
ListUsersRequest
Message for requesting a list of Users
ListUsersResponse
Message for response to listing Users
OAuthCredential
Represents an OAuth token of the account that authorized the Connection, and associated metadata.
OperationMetadata
Represents the metadata of the long-running operation.
Projects
Projects represents the projects to track with the InsightsConfig.
ProviderOAuthConfig
ProviderOAuthConfig is the OAuth config for a provider.
RuntimeConfig
RuntimeConfig represents the runtimes where the application is deployed.
SecureSourceManagerInstanceConfig
Configuration for connections to Secure Source Manager instance
ServiceDirectoryConfig
ServiceDirectoryConfig represents Service Directory configuration for a connection.
StartOAuthRequest
Message for starting an OAuth flow.
StartOAuthResponse
Message for responding to starting an OAuth flow.
UpdateAccountConnectorRequest
Message for updating a AccountConnector
UpdateConnectionRequest
Message for updating a Connection
UpdateInsightsConfigRequest
Request for updating an InsightsConfig.
User
User represents a user connected to the service providers through a AccountConnector.
UserCredential
Represents a personal access token that authorized the Connection, and associated metadata.

Enums

SystemProvider
SystemProvider is a list of providers that are owned by Developer Connect.