#[non_exhaustive]pub struct OAuthParams {
pub code: String,
pub ticket: String,
/* private fields */
}Expand description
The params returned by non-Google OAuth 2.0 flow redirect.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.code: StringRequired. The code to be used for getting the token from SCM provider.
ticket: StringRequired. The ticket to be used for post processing the callback from SCM provider.
Implementations