#[non_exhaustive]pub struct BearerTokenAuthentication {
pub token: Option<Token>,
/* private fields */
}Expand description
Bearer token authentication with a token.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.token: Option<Token>The token to authenticate as.
Implementations
Sourceimpl BearerTokenAuthentication
impl BearerTokenAuthentication
pub fn new() -> Self
Sourcepub fn set_token<T: Into<Option<Token>>>(self, v: T) -> Self
pub fn set_token<T: Into<Option<Token>>>(self, v: T) -> Self
Sets the value of token.
Note that all the setters affecting token are mutually
exclusive.
Example
ⓘ
use google_cloud_developerconnect_v1::model::generic_http_endpoint_config::bearer_token_authentication::Token;
let x = BearerTokenAuthentication::new().set_token(Some(Token::TokenSecretVersion("example".to_string())));Sourcepub fn token_secret_version(&self) -> Option<&String>
pub fn token_secret_version(&self) -> Option<&String>
The value of token
if it holds a TokenSecretVersion, None if the field is not set or
holds a different branch.
Sourcepub fn set_token_secret_version<T: Into<String>>(self, v: T) -> Self
pub fn set_token_secret_version<T: Into<String>>(self, v: T) -> Self