#[non_exhaustive]pub struct ArtifactConfig {
pub uri: String,
pub artifact_storage: Option<ArtifactStorage>,
pub artifact_metadata_storage: Option<ArtifactMetadataStorage>,
/* private fields */
}Expand description
The artifact config of the artifact that is deployed.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.uri: StringRequired. Immutable. The URI of the artifact that is deployed.
e.g. us-docker.pkg.dev/my-project/my-repo/image.
The URI does not include the tag / digest because it captures a lineage of
artifacts.
artifact_storage: Option<ArtifactStorage>The storage location of the artifact.
artifact_metadata_storage: Option<ArtifactMetadataStorage>The storage location of the artifact metadata.
Implementations
Sourceimpl ArtifactConfig
impl ArtifactConfig
Sourcepub fn set_artifact_storage<T: Into<Option<ArtifactStorage>>>(
self,
v: T,
) -> Self
pub fn set_artifact_storage<T: Into<Option<ArtifactStorage>>>( self, v: T, ) -> Self
Sets the value of artifact_storage.
Note that all the setters affecting artifact_storage are mutually
exclusive.
Example
use google_cloud_developerconnect_v1::model::GoogleArtifactRegistry;
let x = ArtifactConfig::new().set_artifact_storage(Some(
google_cloud_developerconnect_v1::model::artifact_config::ArtifactStorage::GoogleArtifactRegistry(GoogleArtifactRegistry::default().into())));Sourcepub fn google_artifact_registry(&self) -> Option<&Box<GoogleArtifactRegistry>>
pub fn google_artifact_registry(&self) -> Option<&Box<GoogleArtifactRegistry>>
The value of artifact_storage
if it holds a GoogleArtifactRegistry, None if the field is not set or
holds a different branch.
Sourcepub fn set_google_artifact_registry<T: Into<Box<GoogleArtifactRegistry>>>(
self,
v: T,
) -> Self
pub fn set_google_artifact_registry<T: Into<Box<GoogleArtifactRegistry>>>( self, v: T, ) -> Self
Sets the value of artifact_storage
to hold a GoogleArtifactRegistry.
Note that all the setters affecting artifact_storage are
mutually exclusive.
Example
use google_cloud_developerconnect_v1::model::GoogleArtifactRegistry;
let x = ArtifactConfig::new().set_google_artifact_registry(GoogleArtifactRegistry::default()/* use setters */);
assert!(x.google_artifact_registry().is_some());Sourcepub fn set_artifact_metadata_storage<T: Into<Option<ArtifactMetadataStorage>>>(
self,
v: T,
) -> Self
pub fn set_artifact_metadata_storage<T: Into<Option<ArtifactMetadataStorage>>>( self, v: T, ) -> Self
Sets the value of artifact_metadata_storage.
Note that all the setters affecting artifact_metadata_storage are mutually
exclusive.
Example
use google_cloud_developerconnect_v1::model::GoogleArtifactAnalysis;
let x = ArtifactConfig::new().set_artifact_metadata_storage(Some(
google_cloud_developerconnect_v1::model::artifact_config::ArtifactMetadataStorage::GoogleArtifactAnalysis(GoogleArtifactAnalysis::default().into())));Sourcepub fn google_artifact_analysis(&self) -> Option<&Box<GoogleArtifactAnalysis>>
pub fn google_artifact_analysis(&self) -> Option<&Box<GoogleArtifactAnalysis>>
The value of artifact_metadata_storage
if it holds a GoogleArtifactAnalysis, None if the field is not set or
holds a different branch.
Sourcepub fn set_google_artifact_analysis<T: Into<Box<GoogleArtifactAnalysis>>>(
self,
v: T,
) -> Self
pub fn set_google_artifact_analysis<T: Into<Box<GoogleArtifactAnalysis>>>( self, v: T, ) -> Self
Sets the value of artifact_metadata_storage
to hold a GoogleArtifactAnalysis.
Note that all the setters affecting artifact_metadata_storage are
mutually exclusive.
Example
use google_cloud_developerconnect_v1::model::GoogleArtifactAnalysis;
let x = ArtifactConfig::new().set_google_artifact_analysis(GoogleArtifactAnalysis::default()/* use setters */);
assert!(x.google_artifact_analysis().is_some());Trait Implementations
Sourceimpl Clone for ArtifactConfig
impl Clone for ArtifactConfig
Sourcefn clone(&self) -> ArtifactConfig
fn clone(&self) -> ArtifactConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ArtifactConfig
impl Debug for ArtifactConfig
Sourceimpl Default for ArtifactConfig
impl Default for ArtifactConfig
Sourcefn default() -> ArtifactConfig
fn default() -> ArtifactConfig
Sourceimpl Message for ArtifactConfig
impl Message for ArtifactConfig
Sourceimpl PartialEq for ArtifactConfig
impl PartialEq for ArtifactConfig
impl StructuralPartialEq for ArtifactConfig