#[non_exhaustive]pub struct ArtifactDeployment {
pub id: String,
pub artifact_reference: String,
pub artifact_alias: String,
pub source_commit_uris: Vec<String>,
pub deploy_time: Option<Timestamp>,
pub undeploy_time: Option<Timestamp>,
pub container_status_summary: String,
/* private fields */
}Expand description
The ArtifactDeployment resource represents the deployment of the artifact within the InsightsConfig resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringOutput only. Unique identifier of ArtifactDeployment.
artifact_reference: StringOutput only. The artifact that is deployed.
artifact_alias: StringOutput only. The artifact alias in the deployment spec, with Tag/SHA. e.g. us-docker.pkg.dev/my-project/my-repo/image:1.0.0
source_commit_uris: Vec<String>Output only. The source commits at which this artifact was built. Extracted from provenance.
deploy_time: Option<Timestamp>Output only. The time at which the deployment was deployed.
undeploy_time: Option<Timestamp>Output only. The time at which the deployment was undeployed, all artifacts are considered undeployed once this time is set.
container_status_summary: StringOutput only. The summary of container status of the artifact deployment.
Format as ContainerStatusState-Reason : restartCount
e.g. “Waiting-ImagePullBackOff : 3”
Implementations
Sourceimpl ArtifactDeployment
impl ArtifactDeployment
Sourcepub fn set_artifact_reference<T: Into<String>>(self, v: T) -> Self
pub fn set_artifact_reference<T: Into<String>>(self, v: T) -> Self
Sets the value of artifact_reference.
Example
let x = ArtifactDeployment::new().set_artifact_reference("example");Sourcepub fn set_artifact_alias<T: Into<String>>(self, v: T) -> Self
pub fn set_artifact_alias<T: Into<String>>(self, v: T) -> Self
Sets the value of artifact_alias.
Example
let x = ArtifactDeployment::new().set_artifact_alias("example");Sourcepub fn set_source_commit_uris<T, V>(self, v: T) -> Self
pub fn set_source_commit_uris<T, V>(self, v: T) -> Self
Sets the value of source_commit_uris.
Example
let x = ArtifactDeployment::new().set_source_commit_uris(["a", "b", "c"]);Sourcepub fn set_deploy_time<T>(self, v: T) -> Self
pub fn set_deploy_time<T>(self, v: T) -> Self
Sets the value of deploy_time.
Example
use wkt::Timestamp;
let x = ArtifactDeployment::new().set_deploy_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_deploy_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_deploy_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of deploy_time.
Example
use wkt::Timestamp;
let x = ArtifactDeployment::new().set_or_clear_deploy_time(Some(Timestamp::default()/* use setters */));
let x = ArtifactDeployment::new().set_or_clear_deploy_time(None::<Timestamp>);Sourcepub fn set_undeploy_time<T>(self, v: T) -> Self
pub fn set_undeploy_time<T>(self, v: T) -> Self
Sets the value of undeploy_time.
Example
use wkt::Timestamp;
let x = ArtifactDeployment::new().set_undeploy_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_undeploy_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_undeploy_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of undeploy_time.
Example
use wkt::Timestamp;
let x = ArtifactDeployment::new().set_or_clear_undeploy_time(Some(Timestamp::default()/* use setters */));
let x = ArtifactDeployment::new().set_or_clear_undeploy_time(None::<Timestamp>);Sourcepub fn set_container_status_summary<T: Into<String>>(self, v: T) -> Self
pub fn set_container_status_summary<T: Into<String>>(self, v: T) -> Self
Sets the value of container_status_summary.
Example
let x = ArtifactDeployment::new().set_container_status_summary("example");Trait Implementations
Sourceimpl Clone for ArtifactDeployment
impl Clone for ArtifactDeployment
Sourcefn clone(&self) -> ArtifactDeployment
fn clone(&self) -> ArtifactDeployment
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ArtifactDeployment
impl Debug for ArtifactDeployment
Sourceimpl Default for ArtifactDeployment
impl Default for ArtifactDeployment
Sourcefn default() -> ArtifactDeployment
fn default() -> ArtifactDeployment
Sourceimpl Message for ArtifactDeployment
impl Message for ArtifactDeployment
Sourceimpl PartialEq for ArtifactDeployment
impl PartialEq for ArtifactDeployment
impl StructuralPartialEq for ArtifactDeployment