#[non_exhaustive]pub struct BitbucketCloudConfig {
pub workspace: String,
pub webhook_secret_secret_version: String,
pub read_authorizer_credential: Option<UserCredential>,
pub authorizer_credential: Option<UserCredential>,
/* private fields */
}Expand description
Configuration for connections to an instance of Bitbucket Cloud.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.workspace: StringRequired. The Bitbucket Cloud Workspace ID to be connected to Google Cloud Platform.
webhook_secret_secret_version: StringRequired. Immutable. SecretManager resource containing the webhook secret
used to verify webhook events, formatted as
projects/*/secrets/*/versions/* or
projects/*/locations/*/secrets/*/versions/* (if regional secrets are
supported in that location). This is used to validate and create webhooks.
Required. An access token with the minimum repository access.
It can either be a workspace, project or repository access token.
It’s recommended to use a system account to generate the credentials.
Required. An access token with the minimum repository, pullrequest and
webhook scope access. It can either be a workspace, project or repository
access token. This is needed to create webhooks. It’s recommended to use a
system account to generate these credentials.
Implementations
Sourceimpl BitbucketCloudConfig
impl BitbucketCloudConfig
Sourcepub fn set_workspace<T: Into<String>>(self, v: T) -> Self
pub fn set_workspace<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_webhook_secret_secret_version<T: Into<String>>(self, v: T) -> Self
pub fn set_webhook_secret_secret_version<T: Into<String>>(self, v: T) -> Self
Sets the value of webhook_secret_secret_version.
Example
let x = BitbucketCloudConfig::new().set_webhook_secret_secret_version("example");Sets the value of read_authorizer_credential.
Example
use google_cloud_developerconnect_v1::model::UserCredential;
let x = BitbucketCloudConfig::new().set_read_authorizer_credential(UserCredential::default()/* use setters */);Sets or clears the value of read_authorizer_credential.
Example
use google_cloud_developerconnect_v1::model::UserCredential;
let x = BitbucketCloudConfig::new().set_or_clear_read_authorizer_credential(Some(UserCredential::default()/* use setters */));
let x = BitbucketCloudConfig::new().set_or_clear_read_authorizer_credential(None::<UserCredential>);Sets the value of authorizer_credential.
Example
use google_cloud_developerconnect_v1::model::UserCredential;
let x = BitbucketCloudConfig::new().set_authorizer_credential(UserCredential::default()/* use setters */);Sets or clears the value of authorizer_credential.
Example
use google_cloud_developerconnect_v1::model::UserCredential;
let x = BitbucketCloudConfig::new().set_or_clear_authorizer_credential(Some(UserCredential::default()/* use setters */));
let x = BitbucketCloudConfig::new().set_or_clear_authorizer_credential(None::<UserCredential>);Trait Implementations
Sourceimpl Clone for BitbucketCloudConfig
impl Clone for BitbucketCloudConfig
Sourcefn clone(&self) -> BitbucketCloudConfig
fn clone(&self) -> BitbucketCloudConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for BitbucketCloudConfig
impl Debug for BitbucketCloudConfig
Sourceimpl Default for BitbucketCloudConfig
impl Default for BitbucketCloudConfig
Sourcefn default() -> BitbucketCloudConfig
fn default() -> BitbucketCloudConfig
Sourceimpl Message for BitbucketCloudConfig
impl Message for BitbucketCloudConfig
Sourceimpl PartialEq for BitbucketCloudConfig
impl PartialEq for BitbucketCloudConfig
impl StructuralPartialEq for BitbucketCloudConfig