#[non_exhaustive]pub struct BitbucketDataCenterConfig {
pub host_uri: String,
pub webhook_secret_secret_version: String,
pub read_authorizer_credential: Option<UserCredential>,
pub authorizer_credential: Option<UserCredential>,
pub service_directory_config: Option<ServiceDirectoryConfig>,
pub ssl_ca_certificate: String,
pub server_version: String,
/* private fields */
}Expand description
Configuration for connections to an instance of Bitbucket Data Center.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.host_uri: StringRequired. The URI of the Bitbucket Data Center host this connection is for.
webhook_secret_secret_version: StringRequired. Immutable. SecretManager resource containing the webhook secret
used to verify webhook events, formatted as
projects/*/secrets/*/versions/* or
projects/*/locations/*/secrets/*/versions/* (if regional secrets are
supported in that location). This is used to validate webhooks.
Required. An http access token with the minimum Repository read access.
It’s recommended to use a system account to generate the credentials.
Required. An http access token with the minimum Repository admin scope
access. This is needed to create webhooks. It’s recommended to use a system
account to generate these credentials.
service_directory_config: Option<ServiceDirectoryConfig>Optional. Configuration for using Service Directory to privately connect to a Bitbucket Data Center instance. This should only be set if the Bitbucket Data Center is hosted on-premises and not reachable by public internet. If this field is left empty, calls to the Bitbucket Data Center will be made over the public internet.
ssl_ca_certificate: StringOptional. SSL certificate authority to trust when making requests to Bitbucket Data Center.
server_version: StringOutput only. Version of the Bitbucket Data Center server running on the
host_uri.
Implementations
Sourceimpl BitbucketDataCenterConfig
impl BitbucketDataCenterConfig
Sourcepub fn set_host_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_host_uri<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_webhook_secret_secret_version<T: Into<String>>(self, v: T) -> Self
pub fn set_webhook_secret_secret_version<T: Into<String>>(self, v: T) -> Self
Sets the value of webhook_secret_secret_version.
Example
let x = BitbucketDataCenterConfig::new().set_webhook_secret_secret_version("example");Sets the value of read_authorizer_credential.
Example
use google_cloud_developerconnect_v1::model::UserCredential;
let x = BitbucketDataCenterConfig::new().set_read_authorizer_credential(UserCredential::default()/* use setters */);Sets or clears the value of read_authorizer_credential.
Example
use google_cloud_developerconnect_v1::model::UserCredential;
let x = BitbucketDataCenterConfig::new().set_or_clear_read_authorizer_credential(Some(UserCredential::default()/* use setters */));
let x = BitbucketDataCenterConfig::new().set_or_clear_read_authorizer_credential(None::<UserCredential>);Sets the value of authorizer_credential.
Example
use google_cloud_developerconnect_v1::model::UserCredential;
let x = BitbucketDataCenterConfig::new().set_authorizer_credential(UserCredential::default()/* use setters */);Sets or clears the value of authorizer_credential.
Example
use google_cloud_developerconnect_v1::model::UserCredential;
let x = BitbucketDataCenterConfig::new().set_or_clear_authorizer_credential(Some(UserCredential::default()/* use setters */));
let x = BitbucketDataCenterConfig::new().set_or_clear_authorizer_credential(None::<UserCredential>);Sourcepub fn set_service_directory_config<T>(self, v: T) -> Selfwhere
T: Into<ServiceDirectoryConfig>,
pub fn set_service_directory_config<T>(self, v: T) -> Selfwhere
T: Into<ServiceDirectoryConfig>,
Sets the value of service_directory_config.
Example
use google_cloud_developerconnect_v1::model::ServiceDirectoryConfig;
let x = BitbucketDataCenterConfig::new().set_service_directory_config(ServiceDirectoryConfig::default()/* use setters */);Sourcepub fn set_or_clear_service_directory_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<ServiceDirectoryConfig>,
pub fn set_or_clear_service_directory_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<ServiceDirectoryConfig>,
Sets or clears the value of service_directory_config.
Example
use google_cloud_developerconnect_v1::model::ServiceDirectoryConfig;
let x = BitbucketDataCenterConfig::new().set_or_clear_service_directory_config(Some(ServiceDirectoryConfig::default()/* use setters */));
let x = BitbucketDataCenterConfig::new().set_or_clear_service_directory_config(None::<ServiceDirectoryConfig>);Sourcepub fn set_ssl_ca_certificate<T: Into<String>>(self, v: T) -> Self
pub fn set_ssl_ca_certificate<T: Into<String>>(self, v: T) -> Self
Sets the value of ssl_ca_certificate.
Example
let x = BitbucketDataCenterConfig::new().set_ssl_ca_certificate("example");Sourcepub fn set_server_version<T: Into<String>>(self, v: T) -> Self
pub fn set_server_version<T: Into<String>>(self, v: T) -> Self
Sets the value of server_version.
Example
let x = BitbucketDataCenterConfig::new().set_server_version("example");Trait Implementations
Sourceimpl Clone for BitbucketDataCenterConfig
impl Clone for BitbucketDataCenterConfig
Sourcefn clone(&self) -> BitbucketDataCenterConfig
fn clone(&self) -> BitbucketDataCenterConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for BitbucketDataCenterConfig
impl Debug for BitbucketDataCenterConfig
Sourceimpl Default for BitbucketDataCenterConfig
impl Default for BitbucketDataCenterConfig
Sourcefn default() -> BitbucketDataCenterConfig
fn default() -> BitbucketDataCenterConfig
Sourceimpl Message for BitbucketDataCenterConfig
impl Message for BitbucketDataCenterConfig
impl StructuralPartialEq for BitbucketDataCenterConfig