#[non_exhaustive]pub struct CreateGitRepositoryLinkRequest {
pub parent: String,
pub git_repository_link: Option<GitRepositoryLink>,
pub git_repository_link_id: String,
pub request_id: String,
pub validate_only: bool,
/* private fields */
}Expand description
Message for creating a GitRepositoryLink
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Value for parent.
git_repository_link: Option<GitRepositoryLink>Required. The resource being created
git_repository_link_id: StringRequired. The ID to use for the repository, which will become the final component of the repository’s resource name. This ID should be unique in the connection. Allows alphanumeric characters and any of -._~%!$&’()*+,;=@.
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
validate_only: boolOptional. If set, validate the request, but do not actually post it.
Implementations
Sourceimpl CreateGitRepositoryLinkRequest
impl CreateGitRepositoryLinkRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_git_repository_link<T>(self, v: T) -> Selfwhere
T: Into<GitRepositoryLink>,
pub fn set_git_repository_link<T>(self, v: T) -> Selfwhere
T: Into<GitRepositoryLink>,
Sets the value of git_repository_link.
Example
use google_cloud_developerconnect_v1::model::GitRepositoryLink;
let x = CreateGitRepositoryLinkRequest::new().set_git_repository_link(GitRepositoryLink::default()/* use setters */);Sourcepub fn set_or_clear_git_repository_link<T>(self, v: Option<T>) -> Selfwhere
T: Into<GitRepositoryLink>,
pub fn set_or_clear_git_repository_link<T>(self, v: Option<T>) -> Selfwhere
T: Into<GitRepositoryLink>,
Sets or clears the value of git_repository_link.
Example
use google_cloud_developerconnect_v1::model::GitRepositoryLink;
let x = CreateGitRepositoryLinkRequest::new().set_or_clear_git_repository_link(Some(GitRepositoryLink::default()/* use setters */));
let x = CreateGitRepositoryLinkRequest::new().set_or_clear_git_repository_link(None::<GitRepositoryLink>);Sourcepub fn set_git_repository_link_id<T: Into<String>>(self, v: T) -> Self
pub fn set_git_repository_link_id<T: Into<String>>(self, v: T) -> Self
Sets the value of git_repository_link_id.
Example
let x = CreateGitRepositoryLinkRequest::new().set_git_repository_link_id("example");Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateGitRepositoryLinkRequest::new().set_request_id("example");Sourcepub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
Sets the value of validate_only.
Example
let x = CreateGitRepositoryLinkRequest::new().set_validate_only(true);Trait Implementations
Sourceimpl Clone for CreateGitRepositoryLinkRequest
impl Clone for CreateGitRepositoryLinkRequest
Sourcefn clone(&self) -> CreateGitRepositoryLinkRequest
fn clone(&self) -> CreateGitRepositoryLinkRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for CreateGitRepositoryLinkRequest
impl Default for CreateGitRepositoryLinkRequest
Sourcefn default() -> CreateGitRepositoryLinkRequest
fn default() -> CreateGitRepositoryLinkRequest
impl StructuralPartialEq for CreateGitRepositoryLinkRequest