#[non_exhaustive]pub struct DeleteAccountConnectorRequest {
pub name: String,
pub request_id: String,
pub validate_only: bool,
pub etag: String,
pub force: bool,
/* private fields */
}Expand description
Message for deleting a AccountConnector
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. Name of the resource
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes after the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
validate_only: boolOptional. If set, validate the request, but do not actually post it.
etag: StringOptional. The current etag of the AccountConnectorn. If an etag is provided and does not match the current etag of the AccountConnector, deletion will be blocked and an ABORTED error will be returned.
force: boolOptional. If set to true, any Users from this AccountConnector will also be deleted. (Otherwise, the request will only work if the AccountConnector has no Users.)
Implementations
Sourceimpl DeleteAccountConnectorRequest
impl DeleteAccountConnectorRequest
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = DeleteAccountConnectorRequest::new().set_request_id("example");Sourcepub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
Sets the value of validate_only.
Example
let x = DeleteAccountConnectorRequest::new().set_validate_only(true);Trait Implementations
Sourceimpl Clone for DeleteAccountConnectorRequest
impl Clone for DeleteAccountConnectorRequest
Sourcefn clone(&self) -> DeleteAccountConnectorRequest
fn clone(&self) -> DeleteAccountConnectorRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for DeleteAccountConnectorRequest
impl Default for DeleteAccountConnectorRequest
Sourcefn default() -> DeleteAccountConnectorRequest
fn default() -> DeleteAccountConnectorRequest
impl StructuralPartialEq for DeleteAccountConnectorRequest