#[non_exhaustive]pub struct GitHubEnterpriseConfig {
pub host_uri: String,
pub app_id: i64,
pub app_slug: String,
pub private_key_secret_version: String,
pub webhook_secret_secret_version: String,
pub app_installation_id: i64,
pub installation_uri: String,
pub service_directory_config: Option<ServiceDirectoryConfig>,
pub server_version: String,
pub ssl_ca_certificate: String,
pub organization: String,
/* private fields */
}Expand description
Configuration for connections to an instance of GitHub Enterprise.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.host_uri: StringRequired. The URI of the GitHub Enterprise host this connection is for.
app_id: i64Optional. ID of the GitHub App created from the manifest.
app_slug: StringOutput only. The URL-friendly name of the GitHub App.
private_key_secret_version: StringOptional. SecretManager resource containing the private key of the GitHub
App, formatted as projects/*/secrets/*/versions/* or
projects/*/locations/*/secrets/*/versions/* (if regional secrets are
supported in that location).
webhook_secret_secret_version: StringOptional. SecretManager resource containing the webhook secret of the
GitHub App, formatted as projects/*/secrets/*/versions/* or
projects/*/locations/*/secrets/*/versions/* (if regional secrets are
supported in that location).
app_installation_id: i64Optional. ID of the installation of the GitHub App.
installation_uri: StringOutput only. The URI to navigate to in order to manage the installation associated with this GitHubEnterpriseConfig.
service_directory_config: Option<ServiceDirectoryConfig>Optional. Configuration for using Service Directory to privately connect to a GitHub Enterprise server. This should only be set if the GitHub Enterprise server is hosted on-premises and not reachable by public internet. If this field is left empty, calls to the GitHub Enterprise server will be made over the public internet.
server_version: StringOutput only. GitHub Enterprise version installed at the host_uri.
ssl_ca_certificate: StringOptional. SSL certificate to use for requests to GitHub Enterprise.
organization: StringOptional. Immutable. GitHub Enterprise organization in which the GitHub App is created.
Implementations
Sourceimpl GitHubEnterpriseConfig
impl GitHubEnterpriseConfig
Sourcepub fn set_host_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_host_uri<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_app_id<T: Into<i64>>(self, v: T) -> Self
pub fn set_app_id<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_app_slug<T: Into<String>>(self, v: T) -> Self
pub fn set_app_slug<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_private_key_secret_version<T: Into<String>>(self, v: T) -> Self
pub fn set_private_key_secret_version<T: Into<String>>(self, v: T) -> Self
Sets the value of private_key_secret_version.
Example
let x = GitHubEnterpriseConfig::new().set_private_key_secret_version("example");Sourcepub fn set_webhook_secret_secret_version<T: Into<String>>(self, v: T) -> Self
pub fn set_webhook_secret_secret_version<T: Into<String>>(self, v: T) -> Self
Sets the value of webhook_secret_secret_version.
Example
let x = GitHubEnterpriseConfig::new().set_webhook_secret_secret_version("example");Sourcepub fn set_app_installation_id<T: Into<i64>>(self, v: T) -> Self
pub fn set_app_installation_id<T: Into<i64>>(self, v: T) -> Self
Sets the value of app_installation_id.
Example
let x = GitHubEnterpriseConfig::new().set_app_installation_id(42);Sourcepub fn set_installation_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_installation_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of installation_uri.
Example
let x = GitHubEnterpriseConfig::new().set_installation_uri("example");Sourcepub fn set_service_directory_config<T>(self, v: T) -> Selfwhere
T: Into<ServiceDirectoryConfig>,
pub fn set_service_directory_config<T>(self, v: T) -> Selfwhere
T: Into<ServiceDirectoryConfig>,
Sets the value of service_directory_config.
Example
use google_cloud_developerconnect_v1::model::ServiceDirectoryConfig;
let x = GitHubEnterpriseConfig::new().set_service_directory_config(ServiceDirectoryConfig::default()/* use setters */);Sourcepub fn set_or_clear_service_directory_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<ServiceDirectoryConfig>,
pub fn set_or_clear_service_directory_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<ServiceDirectoryConfig>,
Sets or clears the value of service_directory_config.
Example
use google_cloud_developerconnect_v1::model::ServiceDirectoryConfig;
let x = GitHubEnterpriseConfig::new().set_or_clear_service_directory_config(Some(ServiceDirectoryConfig::default()/* use setters */));
let x = GitHubEnterpriseConfig::new().set_or_clear_service_directory_config(None::<ServiceDirectoryConfig>);Sourcepub fn set_server_version<T: Into<String>>(self, v: T) -> Self
pub fn set_server_version<T: Into<String>>(self, v: T) -> Self
Sets the value of server_version.
Example
let x = GitHubEnterpriseConfig::new().set_server_version("example");Sourcepub fn set_ssl_ca_certificate<T: Into<String>>(self, v: T) -> Self
pub fn set_ssl_ca_certificate<T: Into<String>>(self, v: T) -> Self
Sets the value of ssl_ca_certificate.
Example
let x = GitHubEnterpriseConfig::new().set_ssl_ca_certificate("example");Sourcepub fn set_organization<T: Into<String>>(self, v: T) -> Self
pub fn set_organization<T: Into<String>>(self, v: T) -> Self
Sets the value of organization.
Example
let x = GitHubEnterpriseConfig::new().set_organization("example");Trait Implementations
Sourceimpl Clone for GitHubEnterpriseConfig
impl Clone for GitHubEnterpriseConfig
Sourcefn clone(&self) -> GitHubEnterpriseConfig
fn clone(&self) -> GitHubEnterpriseConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for GitHubEnterpriseConfig
impl Debug for GitHubEnterpriseConfig
Sourceimpl Default for GitHubEnterpriseConfig
impl Default for GitHubEnterpriseConfig
Sourcefn default() -> GitHubEnterpriseConfig
fn default() -> GitHubEnterpriseConfig
Sourceimpl Message for GitHubEnterpriseConfig
impl Message for GitHubEnterpriseConfig
Sourceimpl PartialEq for GitHubEnterpriseConfig
impl PartialEq for GitHubEnterpriseConfig
impl StructuralPartialEq for GitHubEnterpriseConfig