#[non_exhaustive]pub struct GitLabConfig {
pub webhook_secret_secret_version: String,
pub read_authorizer_credential: Option<UserCredential>,
pub authorizer_credential: Option<UserCredential>,
/* private fields */
}Expand description
Configuration for connections to gitlab.com.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.webhook_secret_secret_version: StringRequired. Immutable. SecretManager resource containing the webhook secret
of a GitLab project, formatted as projects/*/secrets/*/versions/* or
projects/*/locations/*/secrets/*/versions/* (if regional secrets are
supported in that location). This is used to validate webhooks.
Required. A GitLab personal access token with the minimum read_api scope
access and a minimum role of reporter. The GitLab Projects visible to
this Personal Access Token will control which Projects Developer Connect
has access to.
Required. A GitLab personal access token with the minimum api scope
access and a minimum role of maintainer. The GitLab Projects visible to
this Personal Access Token will control which Projects Developer Connect
has access to.
Implementations
Sourceimpl GitLabConfig
impl GitLabConfig
Sourcepub fn set_webhook_secret_secret_version<T: Into<String>>(self, v: T) -> Self
pub fn set_webhook_secret_secret_version<T: Into<String>>(self, v: T) -> Self
Sets the value of webhook_secret_secret_version.
Example
let x = GitLabConfig::new().set_webhook_secret_secret_version("example");Sets the value of read_authorizer_credential.
Example
use google_cloud_developerconnect_v1::model::UserCredential;
let x = GitLabConfig::new().set_read_authorizer_credential(UserCredential::default()/* use setters */);Sets or clears the value of read_authorizer_credential.
Example
use google_cloud_developerconnect_v1::model::UserCredential;
let x = GitLabConfig::new().set_or_clear_read_authorizer_credential(Some(UserCredential::default()/* use setters */));
let x = GitLabConfig::new().set_or_clear_read_authorizer_credential(None::<UserCredential>);Sets the value of authorizer_credential.
Example
use google_cloud_developerconnect_v1::model::UserCredential;
let x = GitLabConfig::new().set_authorizer_credential(UserCredential::default()/* use setters */);Sets or clears the value of authorizer_credential.
Example
use google_cloud_developerconnect_v1::model::UserCredential;
let x = GitLabConfig::new().set_or_clear_authorizer_credential(Some(UserCredential::default()/* use setters */));
let x = GitLabConfig::new().set_or_clear_authorizer_credential(None::<UserCredential>);Trait Implementations
Sourceimpl Clone for GitLabConfig
impl Clone for GitLabConfig
Sourcefn clone(&self) -> GitLabConfig
fn clone(&self) -> GitLabConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for GitLabConfig
impl Debug for GitLabConfig
Sourceimpl Default for GitLabConfig
impl Default for GitLabConfig
Sourcefn default() -> GitLabConfig
fn default() -> GitLabConfig
Sourceimpl Message for GitLabConfig
impl Message for GitLabConfig
Sourceimpl PartialEq for GitLabConfig
impl PartialEq for GitLabConfig
impl StructuralPartialEq for GitLabConfig