#[non_exhaustive]pub struct ListDeploymentEventsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
/* private fields */
}Expand description
Request for requesting list of DeploymentEvents.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent insights config that owns this collection of deployment events. Format: projects/{project}/locations/{location}/insightsConfigs/{insights_config}
page_size: i32Optional. The maximum number of deployment events to return. The service may return fewer than this value. If unspecified, at most 50 deployment events will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
page_token: StringOptional. A page token, received from a previous ListDeploymentEvents
call. Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to ListDeploymentEvents
must match the call that provided the page token.
filter: StringOptional. Filter expression that matches a subset of the DeploymentEvents. https://google.aip.dev/160.
Implementations
Sourceimpl ListDeploymentEventsRequest
impl ListDeploymentEventsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListDeploymentEventsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListDeploymentEventsRequest
impl Clone for ListDeploymentEventsRequest
Sourcefn clone(&self) -> ListDeploymentEventsRequest
fn clone(&self) -> ListDeploymentEventsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ListDeploymentEventsRequest
impl Debug for ListDeploymentEventsRequest
Sourceimpl Default for ListDeploymentEventsRequest
impl Default for ListDeploymentEventsRequest
Sourcefn default() -> ListDeploymentEventsRequest
fn default() -> ListDeploymentEventsRequest
impl StructuralPartialEq for ListDeploymentEventsRequest