#[non_exhaustive]pub struct ListDeploymentEventsResponse {
pub deployment_events: Vec<DeploymentEvent>,
pub next_page_token: String,
/* private fields */
}Expand description
Response to listing DeploymentEvents.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.deployment_events: Vec<DeploymentEvent>The list of DeploymentEvents.
next_page_token: StringA token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
Implementations
Sourceimpl ListDeploymentEventsResponse
impl ListDeploymentEventsResponse
pub fn new() -> Self
Sourcepub fn set_deployment_events<T, V>(self, v: T) -> Self
pub fn set_deployment_events<T, V>(self, v: T) -> Self
Sets the value of deployment_events.
Example
ⓘ
use google_cloud_developerconnect_v1::model::DeploymentEvent;
let x = ListDeploymentEventsResponse::new()
.set_deployment_events([
DeploymentEvent::default()/* use setters */,
DeploymentEvent::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListDeploymentEventsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListDeploymentEventsResponse
impl Clone for ListDeploymentEventsResponse
Sourcefn clone(&self) -> ListDeploymentEventsResponse
fn clone(&self) -> ListDeploymentEventsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListDeploymentEventsResponse
impl Debug for ListDeploymentEventsResponse
Sourceimpl Default for ListDeploymentEventsResponse
impl Default for ListDeploymentEventsResponse
Sourcefn default() -> ListDeploymentEventsResponse
fn default() -> ListDeploymentEventsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListDeploymentEventsResponse
impl PartialEq for ListDeploymentEventsResponse
Sourcefn eq(&self, other: &ListDeploymentEventsResponse) -> bool
fn eq(&self, other: &ListDeploymentEventsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListDeploymentEventsResponse