#[non_exhaustive]pub struct DeploymentEvent {
pub name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub runtime_config: Option<RuntimeConfig>,
pub runtime_deployment_uri: String,
pub state: State,
pub artifact_deployments: Vec<ArtifactDeployment>,
pub deploy_time: Option<Timestamp>,
pub undeploy_time: Option<Timestamp>,
/* private fields */
}Expand description
The DeploymentEvent resource represents the deployment of the artifact within the InsightsConfig resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The name of the DeploymentEvent. This name is provided by Developer Connect insights. Format: projects/{project}/locations/{location}/insightsConfigs/{insights_config}/deploymentEvents/{uuid}
create_time: Option<Timestamp>Output only. The create time of the DeploymentEvent.
update_time: Option<Timestamp>Output only. The update time of the DeploymentEvent.
runtime_config: Option<RuntimeConfig>Output only. The runtime configurations where the DeploymentEvent happened.
runtime_deployment_uri: StringOutput only. The runtime assigned URI of the DeploymentEvent. For GKE, this is the fully qualified replica set uri. e.g. container.googleapis.com/projects/{project}/locations/{location}/clusters/{cluster}/k8s/namespaces/{namespace}/apps/replicasets/{replica-set-id} For Cloud Run, this is the revision name.
state: StateOutput only. The state of the DeploymentEvent.
artifact_deployments: Vec<ArtifactDeployment>Output only. The artifact deployments of the DeploymentEvent. Each artifact deployment contains the artifact uri and the runtime configuration uri. For GKE, this would be all the containers images that are deployed in the pod.
deploy_time: Option<Timestamp>Output only. The time at which the DeploymentEvent was deployed. This would be the min of all ArtifactDeployment deploy_times.
undeploy_time: Option<Timestamp>Output only. The time at which the DeploymentEvent was undeployed, all artifacts are considered undeployed once this time is set. This would be the max of all ArtifactDeployment undeploy_times. If any ArtifactDeployment is still active (i.e. does not have an undeploy_time), this field will be empty.
Implementations
Sourceimpl DeploymentEvent
impl DeploymentEvent
pub fn new() -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = DeploymentEvent::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = DeploymentEvent::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = DeploymentEvent::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = DeploymentEvent::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = DeploymentEvent::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = DeploymentEvent::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_runtime_config<T>(self, v: T) -> Selfwhere
T: Into<RuntimeConfig>,
pub fn set_runtime_config<T>(self, v: T) -> Selfwhere
T: Into<RuntimeConfig>,
Sets the value of runtime_config.
Example
use google_cloud_developerconnect_v1::model::RuntimeConfig;
let x = DeploymentEvent::new().set_runtime_config(RuntimeConfig::default()/* use setters */);Sourcepub fn set_or_clear_runtime_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<RuntimeConfig>,
pub fn set_or_clear_runtime_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<RuntimeConfig>,
Sets or clears the value of runtime_config.
Example
use google_cloud_developerconnect_v1::model::RuntimeConfig;
let x = DeploymentEvent::new().set_or_clear_runtime_config(Some(RuntimeConfig::default()/* use setters */));
let x = DeploymentEvent::new().set_or_clear_runtime_config(None::<RuntimeConfig>);Sourcepub fn set_runtime_deployment_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_runtime_deployment_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of runtime_deployment_uri.
Example
let x = DeploymentEvent::new().set_runtime_deployment_uri("example");Sourcepub fn set_artifact_deployments<T, V>(self, v: T) -> Self
pub fn set_artifact_deployments<T, V>(self, v: T) -> Self
Sets the value of artifact_deployments.
Example
use google_cloud_developerconnect_v1::model::ArtifactDeployment;
let x = DeploymentEvent::new()
.set_artifact_deployments([
ArtifactDeployment::default()/* use setters */,
ArtifactDeployment::default()/* use (different) setters */,
]);Sourcepub fn set_deploy_time<T>(self, v: T) -> Self
pub fn set_deploy_time<T>(self, v: T) -> Self
Sets the value of deploy_time.
Example
use wkt::Timestamp;
let x = DeploymentEvent::new().set_deploy_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_deploy_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_deploy_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of deploy_time.
Example
use wkt::Timestamp;
let x = DeploymentEvent::new().set_or_clear_deploy_time(Some(Timestamp::default()/* use setters */));
let x = DeploymentEvent::new().set_or_clear_deploy_time(None::<Timestamp>);Sourcepub fn set_undeploy_time<T>(self, v: T) -> Self
pub fn set_undeploy_time<T>(self, v: T) -> Self
Sets the value of undeploy_time.
Example
use wkt::Timestamp;
let x = DeploymentEvent::new().set_undeploy_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_undeploy_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_undeploy_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of undeploy_time.
Example
use wkt::Timestamp;
let x = DeploymentEvent::new().set_or_clear_undeploy_time(Some(Timestamp::default()/* use setters */));
let x = DeploymentEvent::new().set_or_clear_undeploy_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for DeploymentEvent
impl Clone for DeploymentEvent
Sourcefn clone(&self) -> DeploymentEvent
fn clone(&self) -> DeploymentEvent
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more