#[non_exhaustive]pub struct FinishOAuthRequest {
pub account_connector: String,
pub params: Option<Params>,
/* private fields */
}Expand description
Message for finishing an OAuth flow.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.account_connector: StringRequired. The resource name of the AccountConnector in the format
projects/*/locations/*/accountConnectors/*.
params: Option<Params>The params returned by OAuth flow redirect.
Implementations
Sourceimpl FinishOAuthRequest
impl FinishOAuthRequest
pub fn new() -> Self
Sourcepub fn set_account_connector<T: Into<String>>(self, v: T) -> Self
pub fn set_account_connector<T: Into<String>>(self, v: T) -> Self
Sets the value of account_connector.
Example
let x = FinishOAuthRequest::new().set_account_connector("example");Sourcepub fn set_params<T: Into<Option<Params>>>(self, v: T) -> Self
pub fn set_params<T: Into<Option<Params>>>(self, v: T) -> Self
Sets the value of params.
Note that all the setters affecting params are mutually
exclusive.
Example
use google_cloud_developerconnect_v1::model::finish_o_auth_request::OAuthParams;
let x = FinishOAuthRequest::new().set_params(Some(
google_cloud_developerconnect_v1::model::finish_o_auth_request::Params::OauthParams(OAuthParams::default().into())));Sourcepub fn oauth_params(&self) -> Option<&Box<OAuthParams>>
pub fn oauth_params(&self) -> Option<&Box<OAuthParams>>
The value of params
if it holds a OauthParams, None if the field is not set or
holds a different branch.
Sourcepub fn set_oauth_params<T: Into<Box<OAuthParams>>>(self, v: T) -> Self
pub fn set_oauth_params<T: Into<Box<OAuthParams>>>(self, v: T) -> Self
Sets the value of params
to hold a OauthParams.
Note that all the setters affecting params are
mutually exclusive.
Example
use google_cloud_developerconnect_v1::model::finish_o_auth_request::OAuthParams;
let x = FinishOAuthRequest::new().set_oauth_params(OAuthParams::default()/* use setters */);
assert!(x.oauth_params().is_some());
assert!(x.google_oauth_params().is_none());Sourcepub fn google_oauth_params(&self) -> Option<&Box<GoogleOAuthParams>>
pub fn google_oauth_params(&self) -> Option<&Box<GoogleOAuthParams>>
The value of params
if it holds a GoogleOauthParams, None if the field is not set or
holds a different branch.
Sourcepub fn set_google_oauth_params<T: Into<Box<GoogleOAuthParams>>>(
self,
v: T,
) -> Self
pub fn set_google_oauth_params<T: Into<Box<GoogleOAuthParams>>>( self, v: T, ) -> Self
Sets the value of params
to hold a GoogleOauthParams.
Note that all the setters affecting params are
mutually exclusive.
Example
use google_cloud_developerconnect_v1::model::finish_o_auth_request::GoogleOAuthParams;
let x = FinishOAuthRequest::new().set_google_oauth_params(GoogleOAuthParams::default()/* use setters */);
assert!(x.google_oauth_params().is_some());
assert!(x.oauth_params().is_none());Trait Implementations
Sourceimpl Clone for FinishOAuthRequest
impl Clone for FinishOAuthRequest
Sourcefn clone(&self) -> FinishOAuthRequest
fn clone(&self) -> FinishOAuthRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more